@@ -167,6 +167,12 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
     # Identifiers for MsgArea messages
     (MSG_SAME, MSG_SLOW_HIGHLIGHT, MSG_SYNCPOINTS) = list(range(3))
 
+    text_windows = {
+        Gtk.TextWindowType.TEXT,
+        Gtk.TextWindowType.LEFT,
+        Gtk.TextWindowType.RIGHT,
+    }
+
     __gsignals__ = {
         'next-conflict-changed': (GObject.SignalFlags.RUN_FIRST, None, (bool, bool)),
         'action-mode-changed': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
@@ -203,6 +209,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
             buf.connect('end_user_action', self.on_textbuffer_end_user_action)
             v.set_buffer(buf)
             buf.data.connect('file-changed', self.notify_file_changed)
+            v.late_bind()
         self._keymask = 0
         self.load_font()
         self.meta = {}
@@ -367,7 +374,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                 views = [self.textview[pane], self.textview[pane - 1]]
                 renderer = GutterRendererChunkAction(pane, pane - 1, views, self, self.linediffer)
                 gutter = t.get_gutter(window)
-                gutter.insert(renderer, 10)
+                gutter.insert(renderer, -40)
 
         self.connect("notify::ignore-blank-lines", self.refresh_comparison)
 
@@ -1501,17 +1508,14 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         if self.num_panes == 1:
             return
 
-        # FIXME: Update to use gtk_cairo_should_draw_window()
+        def should_draw(textwindow):
+            window = textview.get_window(textwindow)
+            if not window:
+                return False
+            return Gtk.cairo_should_draw_window(context, window)
 
-        # if event.window != textview.get_window(Gtk.TextWindowType.TEXT) \
-        #     and event.window != textview.get_window(Gtk.TextWindowType.LEFT):
-        #     return
-
-        # # Hack to redraw the line number gutter used by post-2.10 GtkSourceView
-        # if event.window == textview.get_window(Gtk.TextWindowType.LEFT) and \
-        #    self.in_nested_textview_gutter_expose:
-        #     self.in_nested_textview_gutter_expose = False
-        #     return
+        if not any(should_draw(w) for w in self.text_windows):
+            return
 
         visible = textview.get_visible_rect()
         pane = self.textview.index(textview)
@@ -1598,10 +1602,6 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
             GLib.source_remove(self.anim_source_id[pane])
             self.anim_source_id[pane] = None
 
-        # if event.window == textview.get_window(Gtk.TextWindowType.LEFT):
-        #     self.in_nested_textview_gutter_expose = True
-        #     textview.emit("expose-event", event)
-
     def _get_filename_for_saving(self, title ):
         dialog = Gtk.FileChooserDialog(title,
             parent=self.widget.get_toplevel(),
